@@ -99,6 +99,28 @@ sub sslcipher {
 	return shift->{'SSLCipher'};
 }
 
+sub ID {
+    return shift->{'id'};
+}
+
+sub _on_close
+{
+    my( $self, $sessionID, $state, @args ) = @_;
+    if( $state ) {
+        $self->{OnClose}{ $sessionID } = [ $state, @args ];
+    }
+    else {
+        delete $self->{OnClose}{ $sessionID };
+    }
+}
+ 
+sub DESTROY {
+    my( $self ) = @_;
+    while( my( $sessionID, $data ) = each %{ $self->{OnClose} || {} } ) {
+        $POE::Kernel::poe_kernel->call( $sessionID, @$data );
+    }
+}
+
 # End of module
 1;
 
@@ -132,6 +154,7 @@ POE::Component::Server::SimpleHTTP::Connection - Stores connection information f
 	$connection->dead();		# Returns a boolean value whether the socket is closed or not
 	$connection->ssl();		# Returns a boolean value whether the socket is SSLified or not
 	$connection->sslcipher();	# Returns the SSL Cipher type or undef if not SSL
+	$connection->ID();          # unique ID of this connection
 
 =head2 EXPORT
 
@@ -139,9 +162,8 @@ Nothing.
 
 =head1 SEE ALSO
 
-	L<POE::Component::Server::SimpleHTTP>
-
-	L<POE::Component::Server::SimpleHTTP::Response>
+L<POE::Component::Server::SimpleHTTP>,
+L<POE::Component::Server::SimpleHTTP::Response>
 
 =head1 AUTHOR
 
